@@ -1,7 +1,7 @@
 
 package XML::SRS::Domain::Query;
 BEGIN {
-  $XML::SRS::Domain::Query::VERSION = '0.08';
+  $XML::SRS::Domain::Query::VERSION = '0.09';
 }
 
 use Moose;
@@ -15,6 +15,9 @@ use XML::SRS::FieldList;
 use XML::SRS::Server::Filter::List;
 use XML::SRS::Contact::Filter;
 use XML::SRS::Date::Range;
+use MooseX::Aliases;
+use MooseX::Aliases::Meta::Trait::Attribute;
+
 
 # attributes
 has_attr 'status' =>
@@ -89,6 +92,8 @@ has_element 'registrant_contact_filter' =>
 	xml_nodeName => 'RegistrantContactFilter',
 	xml_required => 0,
 	coerce => 1,
+	traits => [qw(Aliased)],	
+	alias => 'contact_registrant',
 	;
 
 has_element 'admin_contact_filter' =>
@@ -97,6 +102,8 @@ has_element 'admin_contact_filter' =>
 	xml_nodeName => 'AdminContactFilter',
 	xml_required => 0,
 	coerce => 1,
+	traits => [qw(Aliased)],	
+	alias => 'contact_admin',
 	;
 
 has_element 'technical_contact_filter' =>
@@ -105,6 +112,8 @@ has_element 'technical_contact_filter' =>
 	xml_nodeName => 'TechnicalContactFilter',
 	xml_required => 0,
 	coerce => 1,
+	traits => [qw(Aliased)],	
+	alias => 'contact_technical',
 	;
 
 has_element 'result_date_range' =>
